==> whmcs-8.7.2-release.1.zip: crons/domainsync.php <==
<?php //ICB0 72:0 81:f45                                                      ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.7.2 (8.7.2-release.1)                                      *
// * BuildId:5e9b2f1.301                                                  *
// * Build Date:25 Apr 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPuNee5x5D1cHu5erVG0lsXxJNUGxUsolpCOIODx0vuG4IA+scBMmW9vrpq58hhKgP4L0D2LB
NvuFPjUpFqHOuzceAPJqcj3ayd/WHnQhf2dKO9GKz3yqeZwgPz5obejuW9D3n/mK2bE3BrntqkPL
JgaiSJGSmsKCz/iphTv1D7cFeh52lpt8H2+HYdisFypw7MeVK1hRmfrZo4A/dktXdId0KibqksCd
Jh+pa08Y7yHWSlKcB4TWeaSDpv4JMLgpV/ADRVT60s/dbq6i6N4ay736sUhBqSGUlX8KeYaKT9rZ
651Kz6x9GS5e8q539Np5OwbHw5xXzBtzK4xXc9hUNcOrZmbot7dAxSYKh7jruytNP7ftHftGvgiw
pYpS6Cn9bH6faEuhNmfs7TLjikoSlRouLFk6dlIaDf3yjP7wy8Eld2KScl3VYA6YlS+cSdra6iu8
7Unpx4tJOXkuhHxcmC1dTpZwsaR9870FaG04yG/PcSV1hFA+QTStU1mxe2fJBKWrHla5mky3QMx8
jbsDIX1K+Ja/Yr637qxsHzrhKWk0fslgiS1sbO3NZi2yO0ulGE93YQ2cIIJDWeAJRgm+HzBG8165
amlma70jOLTdWpJaSWtGMCb7hzPseCK==
HR+cPv0Q++yj/j/0MAHkp0iN3kuNUIQPz//iXgZ874lqpVuiZ7PIABUMmjZOnTdRak5HML83ATdO
aWHcmEs8QfgYnr1kkRiKu0Gd234t6c5LvIeHP5Hh8nx9LdC5EOxqBBLtskbvv7LoXdiHLbiucmZi
LoM2d6hffziP3fSBO6A9oMfmvO9oM/rf+0GhBNAMuX015V8sYW8PqsGG2BxMvs+O4kPCjK+uf8Ak
5Z4z+RI7TEwVqtuOX2wcIxifs4EGjFRFat4ak67WRoV1Pj5S+0YPX5Qu9W2MP5091PFFMUNsI+PV
Nr8ORyTFb621YXe4Sqb969kY7y1ADFc6ocqnt2tl7MNYOD9hDEdaO+HMlBMxfNxNVzPcaVtPaGeX
kZJXSylmIL41QtoQIoGdTgUA4miVWG8KFl+jRUzi4mhgCZGJrxysk6Jjnopzcz4LswQ8PGaMbux1
Ry1UBOmYr2keS5lTak/HMQuJbwEVdz7u+9rP7/Yyk/yoCgcV9s+4dFUVfyAV8l2HZIhgT+jmUR2+
9y9WSYmunvTL+98xlQqLxWhGU3379YRRKx9m0N8FwTmTsjnnjMPTOLIVWmyqx4Bv4fpe+BOcXmi2
amwIrfz++SGw9hNbsNWmRKxq2/tR1ajuVKFUsg6moZcVZt+D7S4o0R7BW0PT

==> whmcs-8.10.0-release.1.zip: crons/domainsync.php <==
<?php //ICB0 72:0 81:f4d                                                      ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPvv2kodheXyEWl0k2hhHuXViOfFxzFG0NC99pjgQaLrV3Cc6/Vv9KV1Ay9SeoH33vpVvqRve
EAb3tboy8mQFN0SXc5ho2SI91LyOpGevkLyJisEOin/M5WWbvZJIVV0UXAfSeRD+zW4eCfHrAaXn
6ijYQqUSL0YyIdkVJVkAUf2QANRn+jD1yzvDuSJ4snv+v5LItvy/mAnSvdfnbiP0u2sUOCMJcHoJ
t/WJEOCmGz0cCe/xNhBI2w0XBKuKLv65M+13KaYHHjOOKKzQXcl+QBao2WW506PKWx33Uek68Q1Y
OLZ9kcxIw7r78kQgukz650c/2J8JLc2IoIanh2TaQ5LmJ9zs3DT8O9ByN5d7UYEEG4BKDh0qu3l7
0mgaOYrqtRsUpLwAAu4WlU9QffCRtOk1fWzAmbWNcpuDR4NKnbnxPT7468a82RG3o3cMQefIrOt2
CE68PHoBZQPlui+U0F2r7eJchPp6TtGqUfN1obyXiWxCYv4O33r0kAk/O92/TKPvKgq/xpl5O2B9
/JNdHghMJnXtOZKFgslILJXOOLaBuxcDs6YclBEH7WJ7r0sNg10Ep3vleGuRpRkPHh8+9w/UjOe9
PCGaL+ZrTuJEp5CillpO8sKB+qZcZPykrwrhS7hv=
HR+cPubGGgSfeBQ8HExNX2IsrYL6/E5euKxWTgF88NffKRb+Xxc6nceZ3pvQMir+P+8UOPxyjEkj
5+h2x+JHcvOTHOPM5b4zL6PmU30t6UG1zsMl7Gho7M9sIu64tCE+2pMTxjJW61vKCEnvydCRBzS6
enaoCF4AmmnMUJtNGkObre+Exupju57b2H9K7+K1QC5eLSdjRAofUIYW4i1luH57Ud85UvRArPax
V4esg8MtKkYfNPEdGTv0r0zdgdAR5BtL5VXD+MoSGg1wLyuXNlEcAE4idUqrneqdegJgjfKXPj4I
3qrKS74UerFFZqkkpoPxSAH8MVMwkhKmSMOrOwAmELy5lF3GRF9ZNEIhh2sRSy9Yji6i6gHXK0G3
yqwEiZ3ApKgVDVTOZgBq2GdTeAmNPn2DD2bR0mylQ3s80yMxtmNn4Q9r/3NJ0x+G6Su5QONGMyQ9
2h+nj7ZNCyR3UiG76nbxZD1AA8rMzcvAPdLl5giIwk/nTTeoWZjgqfWzW50McN1JSFPDOhszcZZr
m5NEEMPpMRPG1p7dm/skm20Aw+2b73AIP9zbzAllQw63xK7CeB+9fy6NCGvaP2tKKA8RXHfslmsE
cTtQgiUVeQ8JJFrZ5jb8UhAPgf3/T9AZZNoEoGjwfs3+FHG/1hnlUvem
